pub trait TreeExt {
// Required methods
fn entry_names(&self) -> Vec<String>;
fn dir_listing(&self) -> GitDirectory<'_>;
}Expand description
A set of extension methods for the Tree type in git2.
Required Methods
Sourcefn entry_names(&self) -> Vec<String>
fn entry_names(&self) -> Vec<String>
Get a list of all the named entries at this level in the tree.
Sourcefn dir_listing(&self) -> GitDirectory<'_>
fn dir_listing(&self) -> GitDirectory<'_>
Get a higher level, pre-sorted view of this level in the tree analogous to a traditional filesystem, separated into directories and files.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".